@@ -20,6 +20,7 @@
 */
 
 #include "signature.h"
+#include "helper_p.h"
 
 #include "kidentitymanagement_debug.h"
 #include <klocalizedstring.h>
@@ -175,9 +176,9 @@ static QStringList findImageNames(const QString &htmlCode)
     // To complicated for us, so cheat and let a text edit do the hard work
     KPIMTextEdit::RichTextComposer edit;
     edit.setHtml(htmlCode);
-    QList<KPIMTextEdit::ImageWithNamePtr> images = edit.composerControler()->composerImages()->imagesWithName();
+    const QList<KPIMTextEdit::ImageWithNamePtr> images = edit.composerControler()->composerImages()->imagesWithName();
     ret.reserve(images.count());
-    foreach (const KPIMTextEdit::ImageWithNamePtr &image, images) {
+    for (const KPIMTextEdit::ImageWithNamePtr &image : images) {
         ret << image->name;
     }
     return ret;
@@ -198,9 +199,10 @@ void SignaturePrivate::cleanupImages()
 {
     // Remove any images from the internal structure that are no longer there
     if (inlinedHtml) {
-        foreach (const Signature::EmbeddedImagePtr &imageInList, embeddedImages) {
+        foreach (const Signature::EmbeddedImagePtr &imageInList, embeddedImages) { //Don't use for(...:...) here.
             bool found = false;
-            foreach (const QString &imageInHtml, findImageNames(text)) {
+            const QStringList lstImage = findImageNames(text);
+            for (const QString &imageInHtml : lstImage) {
                 if (imageInHtml == imageInList->name) {
                     found = true;
                     break;
@@ -215,7 +217,8 @@ void SignaturePrivate::cleanupImages()
     // Delete all the old image files
     if (!saveLocation.isEmpty()) {
         QDir dir(saveLocation);
-        foreach (const QString &fileName, dir.entryList(QDir::Files | QDir::NoDotAndDotDot | QDir::NoSymLinks)) {
+        const QStringList lst = dir.entryList(QDir::Files | QDir::NoDotAndDotDot | QDir::NoSymLinks);
+        for (const QString &fileName : lst) {
             if (fileName.toLower().endsWith(QLatin1String(".png"))) {
                 qCDebug(KIDENTITYMANAGEMENT_LOG) << "Deleting old image" << dir.path() + fileName;
                 dir.remove(fileName);
@@ -227,7 +230,7 @@ void SignaturePrivate::cleanupImages()
 void SignaturePrivate::saveImages() const
 {
     if (inlinedHtml && !saveLocation.isEmpty()) {
-        foreach (const Signature::EmbeddedImagePtr &image, embeddedImages) {
+        for (const Signature::EmbeddedImagePtr &image : qAsConst(embeddedImages)) {
             QString location = saveLocation + QLatin1Char('/') + image->name;
             if (!image->image.save(location, "PNG")) {
                 qCWarning(KIDENTITYMANAGEMENT_LOG) << "Failed to save image" << location;
@@ -281,7 +284,7 @@ QString SignaturePrivate::textFromCommand(bool *ok) const
         }
         const QString wmsg = i18n("<qt>Failed to execute signature script<p><b>%1</b>:</p>"
                                   "<p>%2</p></qt>", path, QLatin1String(proc.readAllStandardError()));
-        KMessageBox::error(Q_NULLPTR, wmsg);
+        KMessageBox::error(nullptr, wmsg);
         return QString();
     }
 
@@ -317,7 +320,7 @@ void SignaturePrivate::insertSignatureText(Signature::Placement placement, Signa
 
     // We added the text of the signature above, now it is time to add the images as well.
     if (inlinedHtml) {
-        foreach (const Signature::EmbeddedImagePtr &image, embeddedImages) {
+        for (const Signature::EmbeddedImagePtr &image : qAsConst(embeddedImages)) {
             textEdit->composerControler()->composerImages()->loadImage(image->image, image->name, image->name);
         }
     }
@@ -478,7 +481,8 @@ void Signature::readConfig(const KConfigGroup &config)
 
     if (isInlinedHtml() && !d->saveLocation.isEmpty()) {
         QDir dir(d->saveLocation);
-        foreach (const QString &fileName, dir.entryList(QDir::Files | QDir::NoDotAndDotDot | QDir::NoSymLinks)) {
+        const QStringList lst = dir.entryList(QDir::Files | QDir::NoDotAndDotDot | QDir::NoSymLinks);
+        for (const QString &fileName : lst) {
             if (fileName.toLower().endsWith(QLatin1String(".png"))) {
                 QImage image;
                 if (image.load(dir.path() + QLatin1Char('/') + fileName)) {
